@@ -1,4 +1,5 @@
 # -*- coding:utf-8 -*-
+from collections import OrderedDict
 import sqlalchemy.types as t
 from sqlalchemy.inspection import inspect
 from sqlalchemy.orm.properties import ColumnProperty
@@ -115,29 +116,44 @@ class BaseModelWalker(object):
             if set(includes).intersection(excludes):
                 raise InvalidStatus("Conflict includes={}, exclude={}".format(includes, excludes))
 
+# mapper.column_attrs and mapper.attrs is not ordered. define our custom iterate function `iterate'
+
 
 class SingleModelWalker(BaseModelWalker):
+    def iterate(self):
+        for c in self.mapper.local_table.columns:
+            yield self.mapper._props[c.name]  # danger!! not immutable
+
     def walk(self):
-        for prop in self.mapper.attrs:
-            if isinstance(prop, ColumnProperty):
-                if self.includes is None or prop.key in self.includes:
-                    if self.excludes is None or prop.key not in self.excludes:
-                        yield prop
+        for prop in self.iterate():
+            if self.includes is None or prop.key in self.includes:
+                if self.excludes is None or prop.key not in self.excludes:
+                    yield prop
 
 
 class OneModelOnlyWalker(BaseModelWalker):
+    def iterate(self):
+        for c in self.mapper.local_table.columns:
+            yield self.mapper._props[c.name]  # danger!! not immutable
+
     def walk(self):
-        for prop in self.mapper.attrs:
-            if isinstance(prop, ColumnProperty):
-                if self.includes is None or prop.key in self.includes:
-                    if self.excludes is None or prop.key not in self.excludes:
-                        if not any(c.foreign_keys for c in getattr(prop, "columns", Empty)):
-                            yield prop
+        for prop in self.iterate():
+            if self.includes is None or prop.key in self.includes:
+                if self.excludes is None or prop.key not in self.excludes:
+                    if not any(c.foreign_keys for c in getattr(prop, "columns", Empty)):
+                        yield prop
 
 
 class AlsoChildrenWalker(BaseModelWalker):
+    def iterate(self):
+        # self.mapper.attrs
+        for c in self.mapper.local_table.columns:
+            yield self.mapper._props[c.name]  # danger!! not immutable
+        for prop in self.mapper.relationships:
+            yield prop
+
     def walk(self):
-        for prop in self.mapper.attrs:
+        for prop in self.iterate():
             if isinstance(prop, (ColumnProperty, RelationshipProperty)):
                 if self.includes is None or prop.key in self.includes:
                     if self.excludes is None or prop.key not in self.excludes:
@@ -208,7 +224,9 @@ class SchemaFactory(object):
     def __init__(self, walker,
                  classifier=DefaultClassfier,
                  restriction_dict=default_restriction_dict,
+                 container_factory=OrderedDict,
                  child_factory=ChildFactory(".")):
+        self.container_factory = container_factory
         self.classifier = classifier
         self.walker = walker  # class
         self.restriction_dict = restriction_dict
@@ -238,9 +256,9 @@ class SchemaFactory(object):
 
     def _build_properties(self, walker, overrides, depth=None, history=None):
         if depth is not None and depth <= 0:
-            return {}
+            return self.container_factory()
 
-        D = {}
+        D = self.container_factory()
         if history is None:
             history = []
 
