@@ -5,7 +5,10 @@ from .dictify import (
     jsonify,
     dictify,
     normalize,
-    ModelLookup
+    validate_all,
+    ModelLookup,
+    jsonify_dict,
+    normalize_dict,
 )
 from jsonschema import (
     validate,
@@ -15,21 +18,33 @@ from jsonschema.validators import (
     Draft3Validator,
     Draft4Validator
 )
+from . import (
+    default_restriction_dict,
+    default_column_to_schema
+)
+
+
+class DefaultRegistry:
+    jsonify = jsonify_dict
+    normalize = normalize_dict
+    restriction = default_restriction_dict
+    column_to_schema = default_column_to_schema
 
 
 class Mapping(object):
-    def __init__(self, validator, model, modellookup):
+    def __init__(self, validator, model, modellookup, registry=DefaultRegistry):
         self.validator = validator
         self.format_checker = validator.format_checker
         self.schema = validator.schema
         self.model = model
         self.modellookup = modellookup
+        self.registry = registry
 
     def jsondict_from_object(self, ob):
-        return jsonify(ob, self.schema)
+        return jsonify(ob, self.schema, registry=self.registry.jsonify)
 
     def dict_from_jsondict(self, jsondict):
-        return normalize(jsondict, self.schema)
+        return normalize(jsondict, self.schema, registry=self.registry.normalize)
 
     def dict_from_object(self, ob):
         return dictify(ob, self.schema)
@@ -44,19 +59,6 @@ class Mapping(object):
         return validate_all(jsondict, self.validator)
 
 
-class ErrorFound(Exception):  # xxx:
-    pass
-
-
-def validate_all(data, validator):
-    errors = []
-    for e in validator.iter_errors(data):
-        errors.append(dict(name=e.path[0], reason=e.validator))
-    if errors:
-        raise ErrorFound(errors)
-    return None
-
-
 class MappingFactory(object):
     _Mapping = Mapping
     _ModelLookup = ModelLookup
